@@ -11,6 +11,7 @@ class AccountInfo {
 public:
     QString email;
     QString name;
+    QString contact_email;
     qint64 totalStorage;
     qint64 usedStorage;
 };
@@ -116,7 +117,7 @@ public:
     }
 
     QString getEncryptedLibraryPwdHashAlgo() const {
-        return serverInfo.pwdHashAlgo; 
+        return serverInfo.pwdHashAlgo;
     }
 
     QString getEncryptedLibraryPwdHashParams() const {
@@ -138,11 +139,16 @@ public:
     qint32 getTotalStorage() const {
         return accountInfo.totalStorage;
     }
-    
+
     qint32 getUsedStorage() const {
         return accountInfo.usedStorage;
     }
 
+    // The accountInfo.email will be an internal email address if the contact_email exists.
+    QString getDisplayEmail() const {
+        return accountInfo.contact_email.isEmpty() ? accountInfo.email : accountInfo.contact_email;
+    }
+
     QUrl getAbsoluteUrl(const QString& relativeUrl) const;
     QString getSignature() const;
 };
