@@ -37,7 +37,8 @@ SINGLETON_IMPL(DataManager)
 
 DataManager::DataManager()
     : filecache_(FileCache::instance()),
-      dirents_cache_(DirentsCache::instance())
+      dirents_cache_(DirentsCache::instance()),
+      copy_move_in_progress_(false)
 {
 }
 
@@ -619,7 +620,6 @@ QString DataManager::getLocalCachedFile(const QString& repo_id,
     QString local_file_path = getLocalCacheFilePath(repo_id, fpath);
     QFileInfo finfo(local_file_path);
     if (!finfo.exists()) {
-        qWarning ("No cache file for %s\n", toCStr(fpath));
         return "";
     }
 
@@ -675,6 +675,11 @@ FileDownloadTask* DataManager::createDownloadTask(const QString& repo_id,
             this, SLOT(onFileDownloadFinished(bool)), Qt::UniqueConnection);
     setupTaskCleanup(task);
 
+    QFileInfo info(local_path);
+    qInfo() << "[DataManager] download task created, repo_id =" << repo_id
+            << ", path =" << path << ", local_path =" << local_path
+            << ", size =" << info.size() << ", mtime =" << info.lastModified();
+
     return task;
 }
 
@@ -691,32 +696,55 @@ FileDownloadTask* DataManager::createSaveAsTask(const QString& repo_id,
 
 void DataManager::onFileDownloadFinished(bool success)
 {
-    qDebug("[onFileDownloadFinished function] invoked,is success %s",
-           success ? "true" : "false");
     FileDownloadTask *task = qobject_cast<FileDownloadTask *>(sender());
     if (task == NULL)
         return;
-    if (success) {
-        filecache_->saveCachedFileId(task->repoId(),
-                                     task->path(),
-                                     account_.getSignature(),
-                                     task->fileId(),
-                                     task->localFilePath());
-        // TODO we don't want to watch readonly files
-        AutoUpdateManager::instance()->watchCachedFile(account_, task->repoId(), task->path());
-    }
+
+    qInfo() << "[DataManager] download task finished, success =" << success
+            << ", repo_id =" << task->repoId() << ", path =" << task->path();
+
+    if (!success)
+        return;
+
+    QString repo_id    = task->repoId(),
+            path       = task->path(),
+            file_id    = task->fileId(),
+            local_path = task->localFilePath();
+    auto req = new GetRepoRequest(account_, repo_id);
+    connect(req, SIGNAL(failed(const ApiError&)),
+            this, SLOT(onGetRepoFailed(const ApiError&)));
+    connect(req, &GetRepoRequest::success,
+            this, [=](const ServerRepo& repo) {
+                this->onGetRepoSuccess(repo, repo_id, path, file_id, local_path);
+            });
+    req->send();
+}
+
+void DataManager::onGetRepoFailed(const ApiError& error)
+{
+    qWarning() << "onGetRepoFailed" << error.toString();
+}
+
+void DataManager::onGetRepoSuccess(const ServerRepo& repo, QString repo_id, QString path, QString file_id, QString local_path)
+{
+    // The commit_id should not be a null string.
+    QString commit_id = repo.head_commit_id.isEmpty() ? "" : repo.head_commit_id;
+    filecache_->saveCachedFileId(repo_id, path, account_.getSignature(), file_id, commit_id, local_path);
+
+    AutoUpdateManager::instance()->watchCachedFile(account_, repo_id, path);
 }
 
 FileUploadTask* DataManager::createUploadTask(const QString& repo_id,
                                               const QString& parent_dir,
                                               const QString& local_path,
+                                              const QString& commit_id,
                                               const QString& name,
                                               const bool overwrite)
 {
     FileUploadTask *task;
     if (QFileInfo(local_path).isFile())
         task = new FileUploadTask(account_, repo_id, parent_dir,
-                                  local_path, name, !overwrite);
+                                  local_path, commit_id, name, !overwrite);
     else
         task = new FileUploadDirectoryTask(account_, repo_id, parent_dir,
                                            local_path, name);
@@ -724,6 +752,13 @@ FileUploadTask* DataManager::createUploadTask(const QString& repo_id,
             this, SLOT(onFileUploadFinished(bool)));
     setupTaskCleanup(task);
 
+    QFileInfo info(local_path);
+    qInfo() << "[DataManager] upload task created, repo_id =" << repo_id
+            << ", parent_dir =" << parent_dir << ", local_path =" << local_path
+            << ", commit_id =" << commit_id << ", name =" << name
+            << ", overwrite =" << overwrite << ", size =" << info.size()
+            << ", mtime =" << info.lastModified();
+
     return task;
 }
 
@@ -746,6 +781,12 @@ FileUploadTask* DataManager::createUploadMultipleTask(const QString& repo_id,
             this, SLOT(onFileUploadFinished(bool)));
     setupTaskCleanup(task);
 
+    QFileInfo info(local_path);
+    qInfo() << "[DataManager] upload multiple task created, repo_id =" << repo_id
+            << ", parent_dir =" << parent_dir << ", local_path =" << local_path
+            << ", names =" << names << ", overwrite =" << overwrite
+            << ", size =" << info.size() << ", mtime =" << info.lastModified();
+
     return task;
 }
 
@@ -754,6 +795,10 @@ void DataManager::onFileUploadFinished(bool success)
     FileUploadTask *task = qobject_cast<FileUploadTask *>(sender());
     if (task == NULL)
         return;
+
+    qInfo() << "[DataManager] upload (multiple) task finished, success =" << success
+            << ", repo_id =" << task->repoId() << ", path =" << task->path();
+
     if (success) {
         //expire the parent path
         dirents_cache_->expireCachedDirents(task->repoId(),
